Stan Math Library: stan/math/rev/core/v_vari.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
v_vari.hpp File Reference
`#include <stan/math/rev/core/vari.hpp>`

Go to the source code of this file.

## Classes
class | stan::math::op_v_vari

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.